/*
  GetCharState.ino

  This sketch demonstrats how GetCharState function works.

  You have to install MGLCD library Ver.0.34 or later, which controls 
a GLCD module.  MGLCD library can be downloaded at the following web page:

  http://www3.big.or.jp/~schaft/hardware/MGLCD/

  This sketch shows the state of your keypad on your LCD screen.

  This sketch requires a 122X32 MGLCD shield that is introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product_MGLCD_shield_12232_C/index.html

  This sketch also requires a resistive voltage divider keypad.
This sketch assumes that you use the 4X4 keypad introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product/keypad4X4/page001.html

  This example code is in the public domain.
*/

// include library codes
#include <mglcd.h> // library for LCD
#include <ResKeypad.h> // library for keypad

// variables
#ifdef USBCON // Leonardo
mglcd_serial MGLCD(&Serial1,500000); // define serial LCD
#else // not Leonardo
mglcd_serial MGLCD(&Serial,500000); // define serial LCD
#endif

ResKeypad keypad(A4,16,RESKEYPAD_4X4); // define keypad

// functions
void setup()
{
  // initialize LCD
  while(MGLCD.Reset());
} // setup

void loop()
{
  static signed char LastKey=-2; // key number obtained by last GetKeyState() call
  char CurrentKey;

  CurrentKey=keypad.GetKeyState();
  if(CurrentKey!=LastKey) {
    MGLCD.Locate(0,0);
    MGLCD.ClearRestOfLine();
    if(CurrentKey<0) {
      MGLCD.print("No key is pressed.");
    } else {
      MGLCD.print("SW");
      MGLCD.print(CurrentKey+1);
      MGLCD.print(" is pressed.");
    } // if
    LastKey=CurrentKey;
  } // if
} // loop
