/*
  GetChar.ino

  This sketch demonstrats how GetChar function works.

  You have to install MGLCD library Ver.0.34 or later, which controls 
a GLCD module.  MGLCD library can be downloaded at the following web page:

  http://www3.big.or.jp/~schaft/hardware/MGLCD/

  This sketch shows the keys you pressed on your LCD screen.

  This sketch requires a GLCD-learning shield that is introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product_GlcdLearning/page001.html

  This sketch also requires a resistive voltage divider keypad.
This sketch assumes that you use the 4X4 keypad introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product/keypad4X4/page001.html

  This example code is in the public domain.
*/

// include library codes
#include <mglcd.h> // library for LCD
#include <ResKeypad.h> // library for keypad

// variables
const TLcdPinAssignTable PinAssignTable={ // pin assignments for LCD
    A0_DI  : A3, // A0
    CS1_E1 : A0, // E1
    CS2_E2 : A1, // E2
    E      : MGLCD_UNUSED_PIN,
    RW     : A2,
    DB0    : 8 ,
    DB1    : 9 ,
    DB2    : 10,
    DB3    : 11,
    DB4    : 4 ,
    DB5    : 5 ,
    DB6    : 6,
    DB7    : 7
}; // PinAssignTable;

mglcd_S12232ZA MGLCD(PinAssignTable); // define pin assignments of LCD
ResKeypad keypad(A4,16,RESKEYPAD_4X4,RESKEYPAD_4X4_SIDE_A); // enable this line if SIDE A of keypad is used
//ResKeypad keypad(A4,16,RESKEYPAD_4X4,RESKEYPAD_4X4_SIDE_B); // enable this line if SIDE B of keypad is used

// functions
void setup()
{
  // enable charge pump circuit that yield negative supply for LCD BIAS
  pinMode(3,OUTPUT);
  analogWrite(3,127);

  // initialize LCD
  while(MGLCD.Reset());
  MGLCD.Locate(0,0);
  MGLCD.print("Press keys.");
  MGLCD.Locate(0,1);
} // setup

void loop()
{
  char c;

  c=keypad.GetChar();
  if(c!='\0') {
    MGLCD.print(c); // show the character for the kyou you pressed
  } // if
} // loop
